if select(6, GetAddOnInfo("PitBull_" .. (debugstack():match("[d%.][d%.][O%.]ns\\PitBull\\(.-)\\") or ""))) ~= "MISSING" then return end

local VERSION = tonumber(("$Revision: 39928 $"):match("%d+"))

local L = AceLibrary("AceLocale-2.2"):new("PitBull_Banzai")
L:RegisterTranslations("enUS", function() return {
	["Aggro color"] = true,
	["Sets which color to use on the health bar of units that have aggro."] = true,
	["Enable aggro indicator"] = true,
	["Change the color of this unit's health bar when it gets aggro."] = true,
} end)

PitBull_Banzai = PitBull:NewModule("Banzai", "AceEvent-2.0", "AceHook-2.1")
local PitBull_Banzai = PitBull_Banzai
local self = PitBull_Banzai
if PitBull.revision < VERSION then
	PitBull.version = "r" .. VERSION
	PitBull.revision = VERSION
	PitBull.date = ("$Date: 2007-06-14 16:32:38 -0400 (Thu, 14 Jun 2007) $"):match("%d%d%d%d%-%d%d%-%d%d")
end
self.desc = "Adds aggro coloring to PitBull."

local PitBull_HealthBarBar = PitBull:GetModule("HealthBar")

local banzai
local enabled = nil
local db = nil
local backgroundColors = {0, 0, 0, 1}

local function updateBGColor(color)
	for i, v in ipairs(color) do
		backgroundColors[i] = (v + 0.2) / 3
	end
	backgroundColors[4] = 1
end

function PitBull_Banzai:OnInitialize()
	self.db = PitBull:AcquireDBNamespace("Banzai")
	PitBull:RegisterDefaults("Banzai", "profile", {
		color = {1.0, 0, 0, 1.0},
		groups = {
			target = {
				ignore = true,
			},
			targettarget = {
				ignore = true,
			},
			targettargettarget = {
				ignore = true,
			},
			["*"] = {},
		}
	})
	db = self.db.profile.groups
	updateBGColor(self.db.profile.color)
end

function PitBull_Banzai:Enable()
	self:OnEnable()
end

function PitBull_Banzai:Disable()
	if enabled then
		self:UnregisterAllEvents()
		self:UnhookAll()
		enabled = nil
	end
end

function PitBull_Banzai:OnEnable()
	if not enabled then
		if not AceLibrary:HasInstance("Banzai-1.1") then
			error("PitBull_Banzai requires the library Banzai-1.1 to be available.")
		end
		banzai = AceLibrary("Banzai-1.1")
		self:RegisterEvent("Banzai_UnitGainedAggro", "AggroChanged")
		self:RegisterEvent("Banzai_UnitLostAggro", "AggroChanged")
		self:Hook(PitBull_HealthBar, "UpdateHealthbarColor")
		enabled = true
	end
end

function PitBull_Banzai:AggroChanged(unitId)
	for frame in PitBull:IterateUnitFramesForUnit(unitId) do
		if frame and not db[frame.group].ignore then
			self:UpdateHealthbarColor(PitBull_HealthBar, unitId, frame)
		end
	end
end

function PitBull_Banzai:UpdateHealthbarColor(module, unit, frame)
	if not db[frame.group].ignore then
		local aggro = banzai:GetUnitAggroByUnitId(unit)
		if aggro then
			local color = self.db.profile.color
			if PitBull_HealthBar.db.profile[frame.group].reverse then
				frame.healthBar:SetStatusBarColor(unpack(backgroundColors))
				frame.healthBar.bg:SetVertexColor(unpack(color))
			else
				frame.healthBar:SetStatusBarColor(unpack(color))
				frame.healthBar.bg:SetVertexColor(unpack(backgroundColors))
			end
			return
		end
	end
	self.hooks[module].UpdateHealthbarColor(module, unit, frame)
end
-- Global Options
local function getColor()
	return unpack(PitBull_Banzai.db.profile.color)
end
local function setColor(r, g, b, a)
	PitBull_Banzai.db.profile.color = {r, g, b, a}
	updateBGColor(PitBull_Banzai.db.profile.color)
	for unit,frame in PitBull:IterateUnitFrames() do
		PitBull_Banzai:UpdateHealthbarColor(PitBull_HealthBar, unit, frame)
	end
end
PitBull.options.args.global.args.colors.args.banzai = {
	type = "color",
	name = L["Aggro color"],
	desc = L["Sets which color to use on the health bar of units that have aggro."],
	get = getColor,
	set = setColor,
}
-- Unit/Group Specific Options
local function getEnabled(group)
	return not PitBull_Banzai.db.profile.groups[group].ignore
end
local function setEnabled(group, value)
	PitBull_Banzai.db.profile.groups[group].ignore = not value
	for unit, frame in PitBull:IterateUnitFramesByGroup(group) do
		PitBull_Banzai:UpdateHealthbarColor(PitBull_HealthBar, unit, frame)
	end
end
PitBull_Banzai:RegisterPitBullOptionsMethod(function(group)
	return {
		type = "toggle",
		name = L["Enable aggro indicator"],
		desc = L["Change the color of this unit's health bar when it gets aggro."],
		get = getEnabled,
		set = setEnabled,
		passValue = group,
	}
end)

